/*************************************************
   Digital voltmeter using an
   Maxim MAX1241 ADC
   connected to an AT90S8515
   using the SPI bus
   The measured voltage is transmitted
   through the STK200 RS232 interface
   Communication parameters: 9600 8N1

   CodeVisionAVR C Compiler
   (C) 1998-2000 Pavel Haiduc, HP InfoTech S.R.L.

   Chip type        : AT90S8515
   Clock frequency  : 4.000000 MHz
   Memory model     : Small
   Internal RAM size: 512
   External RAM size: 0
   Data Stack size  : 128
*************************************************

 	MAX1241 connections to the AT90S8515

	[MAX1241] [AT9S8515 DIP40]
	1 VDD=5V
	2 Vin
	3 /SHDN - 1  PB0
	4 REF=5V
	5 GND   - 20 GND
	6 DOUT  - 7  MISO
	7 /CS   - 2  PB1
	8 SCLK  - 8  SCK

   THE ISP CABLE SHOULD BE DISCONNECTED FROM
   THE STK200 BOARD AFTER PROGRAMMING THE CHIP!
*/

#include <90s4414.h>

// Standard Input/Output functions
#include <stdio.h>

// SPI functions
//#include <spi.h>

// delays
#include <delay.h>

// MAX1241 Voltage Reference [mV]
#define VREF 5000

// MAX1241 control signals definitions
#define NSHDN PORTB.0
#define NCS PORTB.1
#define DOUT PINB.6

          
void main(void)
{
// store the conversion result here
unsigned n;      
char *mystr;

// Input/Output Ports initialization
// Port A
DDRA=0x00;
PORTA=0x00;

// Port B
// the /SS pin is set as an output
// with level 1, it's required by
// the SPI to work in master mode
DDRB=0xA3;
PORTB=0x12;

// Port C
DDRC=0x00;
PORTC=0x00;

// Port D
DDRD=0x00;
PORTD=0x00;

// UART initialization
// Communication Parameters: 8 Data, 1 Stop, No Parity
// UART Receiver: On
// UART Transmitter: On
UCR=0x18;
// UART Baud rate: 9600
UBRR=0x19;

// SPI initialization
// SPI Type: Master
// SPI Clock Rate: 1000.000 kHz
// SPI Clock Phase: Cycle Half
// SPI Clock Polarity: Low
// SPI Data Order: MSB First
//SPCR=0x50;

//putsf("MAX1241 Demo using the CodeVisionAVR C Compiler");
//putsf("***********************************************\n");

// Make AD conversions and send the results to RS232
n=0;
while (1)
      {
      //n=max1241_read();
      n++;                     
      printf("Test %4u \n",n);
      //printf("Test %4u and %s \n",n,mystr);
      //mystr = scanf();
      //mystr = scanf("%s");
      // 0.3 sec. delay
      delay_ms(300);  
      if(n==8) {
      	n = 0;
      } //end if  
      
      
}; //end while
} //end main
